# floodam.building 1.5.0.2

## Bugs 

* `is_compatible_python()` (internal)
    - Really solved bug provoking error when loading the library
    (coming from change in R version 4.4 and management of `x < 3` when x is a
    character)
    - test added
    
# floodam.building 1.5.0.1

## Bugs 

* `is_compatible_python()` (internal)
    - new name for `compatible_python()`
    - Solved bug provoking error when loading the library

# floodam.building 1.5.0.0

## Enhancements
* `adjust_elementary_damaging()`
    - `stop()` sequence when checking parameter *damaging* removed. Now the
    function returns NULL if parameter *damaging* is NULL, allowing the estimate
    of the building's damage function ignoring missing elementary components
* `compute_damage()`
    - use of `message()` instead of `cat()` for `verbose` or `talkative` mode
    - new management of missing elementary component:
        - if some elementary components ar missing (i.e. are not present in
        `DAM`), then `compute_damage()` does not return NULL. It continues the
        calculation, consistent with  new behavior of
        `adjust_elementary_damaging()`.
        - a message and a warning are sent to inform the user that the
        estimation will be done ignoring those elementary components.
* `check_damaging()`
    - Modified warning message, consistent with new behavior of
    `adjust_elementary_damaging()`
    - Modified log message, consistent with new behavior of
    `adjust_elementary_damaging()`
    - variable *missing* renamed to *missing_component* to avoid confusion with
    the `base::missing()` function
* `load_model()`
    - no use of `options(warn)` to be better tested with
    `testthat::expect_warning()`
* `order_wall()`
    - no use of `options(warn)` to be better tested with
    `testthat::expect_warning()`
* `to_numeric()` (internal)
    - extracted from `loead_model()`, to deal with 'clever' transformation from
    character to numeric
    - test added
* `remove_comment()` (internal)
    - extracted from `loead_model()`, to deal with removal of comments when
    reading xml files
    - test to be added

## Data

* New model available in inst/extdata:
    - *adu_t_missing* is similar to *adu_t* with missing elementary components

# floodam.building 1.4.1.0

## Data

* New model *dwelling* available as package data
* New model available in inst/extdata:
    - *adu_t_bassement* is two storey dwelling composed of a single-room
    basement and a 4-room ground floor (3 rooms around a central room)
* Furniture included in models *adu_t* and *adu_t_basement*

## Documentation

* New vignette explaining how to model +1 storey buildings
* New vignette explaining how to handle furniture
* Update of function examples

## Bugs 

* `analyse_hydraulics()`
    - Solved bug provoking error when function called

# floodam.building 1.4.0.2

## Bugs

* `load_model()`
    - keep only one category of elementary components when too many are found
    and generate a warning
* `COMPONENT_ELEMENTARY`
    - keep only one category for activities' elementary components
* `analyse_hydraulics()`
    - adapt to reticulate's strange way of calling attribute

# floodam.building 1.4.0.1

## Enhancements
* `create_new_model()`
    - New *metadata* value for the input_file parameter to generate, from an
    internal template, the metadata file to be inputted

## Documentation

* Update and bug handling of function examples

# floodam.building 1.4.0.0

## Enhancements

* COMPONENT_ELEMENTARY
    - Elementary vulnerability function categories in variable
    `category_vulnerability` deduplicated and relabeled

# floodam.building 1.3.2.0

## Enhancements

* `analyse_hydraulics()`
    - The function now executes the hydraulic module of floodam.building in
    either the default python virtual environment "floodam" or in a user-defined
    python virtual environment, provided using the new parameter `envname`.
* `manage_python()`
    - Function to manage the installation of python dependencies needed by the
    hydraulic module of floodam.building. It creates a virtual environment to
    avoid system pollution or dependency conflicts.
* `compatible_python()` (internal)
    - Internal function that checks whether Python 3 is installed
* `py_simulate_hydraulics()` (internal)
    - replace `sim_hydrau_py()`
    - execute the hydraulic module of floodam.building in either the default
    python virtual environment, "floodam", or in a user-defined python virtual
    environment, provided using the new parameter `envname`. 
* `plot.damaging()`
    * Finalization of snake_case transformation for internal functions.
* `plot.model()`
    * Finalization of snake_case transformation for internal functions.

## Documentation

* Cover page of website
    - Modification of installation instructions

# floodam.building 1.3.1.1

## Bugs

* `compute_damage()`
    - Solved bug provoking error when function called from function
    apply_measure()
* `create_new_model()`
    - export added

# floodam.building 1.3.1.0

## Enhancements

* `create_new_model()`
    - Function to generate template for new model

## Documentation

* Vignettes 
    - *The structure of the input file of floodam.building*
    - *From the architect's plan to the input file of floodam.building*

## Dependencies 

* R
    - Package `DT`
    - Package `htmltools`

# floodam.building 1.3.0.0

## Enhancements

* `analyse_hydraulics()`
    - Function to simulate the hydraulics in the interior of the building
* `analyse_model()`
    - New stage "hydraulic"
* `extract_hydraulic_input()`
    - Function called by `analyse_model()` to generate input on exchanges
    through openings
    - Called when "hydraulic" is given as `stage`
* `generate_limnigraph()`
    - Function to generate limnigraph (evolution of water depth against time)
* New global variables (input needed by hydraulic simulator)
    - `floodam_building_hydraulic_discharge_coefficient`, default value 0.42
    - `floodam_building_hydraulic_initial_water_depth_interior` default value 0
    - `floodam_building_hydraulic_closed_opening_clearance` default value 0.5
* New optional tags in XML input to facilitate the identification of water
    exchanges through openings and *empty* walls
    - opening names
    - wall names

## Data

* dwelling models in inst/extdata:
    - *adu_l* is a single storey linear 4-room dwelling
    - *adu_t* is a single storey 4-room dwelling; 3 rooms around a central room
    - *adu_t_2room* is a single storey 2-room dwelling; created by merging rooms
    in *adu_t*
    - *adu_t_invisible* is similar to *adu_t_2room* but instead of merged, rooms
    are separated by invisible walls

## Documentation

* Vignettes 
    - *Getting started with floodam.building*
    - *Simulating the hydraulic behavior of the interior of a building
    (English)*

* *How to install python dependencies*

## Dependencies 

* R
    - Package `reticulate`
* Python
    - Python 3
    - Package `NumPy`
    - Package `pandas`
