% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analyse_hydraulics.R
\name{analyse_hydraulics}
\alias{analyse_hydraulics}
\title{Analyse the hydraulics of the maquette}
\usage{
analyse_hydraulics(
  model,
  limnigraph,
  flood_duration,
  opening_scenario = c("open", "closed", "combined", "user_def"),
  exchange,
  envname = "floodam",
  sim_id = NULL,
  filename = NULL,
  verbose = getOption("floodam_building_verbose")
)
}
\arguments{
\item{model}{either a character, name given to the model or an object of
class model}

\item{limnigraph}{numeric, matrix of floodwater depth heights by instant t
for each exterior opening exposed to flooding}

\item{flood_duration}{numeric, duration of the flood event in seconds,
optional; if not provided, calculated using limnigraph}

\item{opening_scenario}{character, one of the following options: "open",
"closed", "combined" or "user_def"}

\item{exchange}{character, user-defined scenario of exchanges; use in case
opening_scenario = "user_def", ignore otherwise}

\item{envname}{character; name of the python's virtual environment.
Default to "floodam"}

\item{sim_id}{character, optional; id of simulation if function called from a
loop}

\item{filename}{character, optional; file name without extension to be given
to simulation's output wen saving to disk}

\item{verbose}{boolean, will floodam tells what it is doing, default to
getOption("floodam_building_verbose")}
}
\value{
data.frame of hydraulic values: water exchanges through openings and
	floodwater depth in rooms
}
\description{
{
"open": scenario where all openings are open
"closed": scenario where all openings are closed
"combined": scenario where all exterior openings are closed and all interior
		openings are open
"user_def": user-defined scenario

When not provided, the flood duration is calculated using the limnigraph as
follows: final time in limnigraph + half an hour.
}
}
