% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generate_limnigraph.R
\name{generate_limnigraph}
\alias{generate_limnigraph}
\title{build limnigraph for interior hydraulic simulation}
\usage{
generate_limnigraph(
  model,
  time,
  depth,
  exposed_openings,
  verbose = getOption("floodam_building_verbose")
)
}
\arguments{
\item{model}{either a character, name given to the model or an object of class model}

\item{time}{numeric, vector of time steps (in seconds) at which a specific floodwater depth is reached}

\item{depth}{numeric, vector of floodwater depth (in meters) for each time step}

\item{exposed_openings}{character, vector of names of openings to the outside exposed to floods in model}

\item{verbose}{boolean, will floodam tells what it is doing, default to getOption("floodam_building_verbose")}
}
\value{
matrix containing the limnigraph
}
\description{
build limnigraph for interior hydraulic simulation
}
\examples{

# using already loaded library model 'dwelling'
model = dwelling

# analyzing model using the steps *extract* and *hydraulic* 
model = analyse_model(model = dwelling, stage = c("extract", "hydraulic"))

# generating the limnigraph for the N openings of the modeled dwelling 
flood = generate_limnigraph(
     model = model,
     time = c(0, 5400, 10800),
     depth = c(0,3,0),
     exposed_openings = c("door1", "window1", "window2")
 )

}
